@@ -1151,7 +1151,7 @@ gedit_document_set_location (GeditDocument *doc,
 
 /**
  * gedit_document_get_uri_for_display:
- * @doc:
+ * @doc: a #GeditDocument.
  *
  * Note: this never returns %NULL.
  **/
@@ -1173,7 +1173,7 @@ gedit_document_get_uri_for_display (GeditDocument *doc)
 
 /**
  * gedit_document_get_short_name_for_display:
- * @doc:
+ * @doc: a #GeditDocument.
  *
  * Note: this never returns %NULL.
  **/
@@ -1224,7 +1224,7 @@ gedit_document_get_content_type (GeditDocument *doc)
 
 /**
  * gedit_document_get_mime_type:
- * @doc:
+ * @doc: a #GeditDocument.
  *
  * Note: this never returns %NULL.
  **/
@@ -1778,6 +1778,7 @@ gedit_document_save (GeditDocument          *doc,
  * @location: the location where to save the document.
  * @encoding: the #GeditEncoding to encode the document.
  * @newline_type: the #GeditDocumentNewlineType for the document.
+ * @compression_type: the compression type for the file.
  * @flags: optionnal #GeditDocumentSaveFlags.
  *
  * Save the document to a new location. This results in the "save" signal
@@ -2528,9 +2529,24 @@ connect_search_settings (GeditDocument *doc)
 				 G_CONNECT_SWAPPED);
 }
 
+/**
+ * gedit_document_set_search_context:
+ * @doc: a #GeditDocument
+ * @search_context: (allow-none): the new #GtkSourceSearchContext
+ *
+ * Sets the new search context for the document. Use this function only when the
+ * search occurrences are highlighted. So this function should not be used for
+ * background searches. The purpose is to have only one highlighted search
+ * context at a time in the document.
+ *
+ * After using this function, you should unref the @search_context. The @doc
+ * should be the only owner of the @search_context, so that the Clear Highlight
+ * action works. If you need the @search_context after calling this function,
+ * use gedit_document_get_search_context().
+ */
 void
-_gedit_document_set_search_context (GeditDocument          *doc,
-				    GtkSourceSearchContext *search_context)
+gedit_document_set_search_context (GeditDocument          *doc,
+				   GtkSourceSearchContext *search_context)
 {
 	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
 
@@ -2565,8 +2581,21 @@ _gedit_document_set_search_context (GeditDocument          *doc,
 	update_empty_search (doc);
 }
 
+/**
+ * gedit_document_get_search_context:
+ * @doc: a #GeditDocument
+ *
+ * Gets the search context. Use this function only if you have used
+ * gedit_document_set_search_context() before. You should not alter other search
+ * contexts, so you have to verify that the returned search context is yours.
+ * One way to verify that is to compare the search settings object, or to mark
+ * the search context with g_object_set_data().
+ *
+ * Returns: (transfer none): the current search context of the document, or NULL
+ * if there is no current search context.
+ */
 GtkSourceSearchContext *
-_gedit_document_get_search_context (GeditDocument *doc)
+gedit_document_get_search_context (GeditDocument *doc)
 {
 	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), NULL);
 
