@@ -15,15 +15,13 @@
  *  GNU Library General Public License for more details.
  *
  *  You should have received a copy of the GNU Library General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __GEDIT_WINDOW_ACTIVATABLE_H__
 #define __GEDIT_WINDOW_ACTIVATABLE_H__
 
 #include <glib-object.h>
-#include <gedit/gedit-menu-extension.h>
 
 G_BEGIN_DECLS
 
@@ -58,18 +56,8 @@ void	 gedit_window_activatable_activate	(GeditWindowActivatable *activatable);
 void	 gedit_window_activatable_deactivate	(GeditWindowActivatable *activatable);
 void	 gedit_window_activatable_update_state	(GeditWindowActivatable *activatable);
 
-/**
- * gedit_window_activatable_extend_gear_menu:
- * @activatable: A #GeditWindowActivatable.
- * @extension_point: the extension point section of the menu to get.
- *
- * Gets the #GeditMenuExtension for the gear menu @extension_point.
- *
- * Returns: (transfer full): a #GeditMenuExtension for the specific section or %NULL if not found.
- */
-GeditMenuExtension *gedit_window_activatable_extend_gear_menu (GeditWindowActivatable *activatable,
-                                                                const gchar            *extension_point);
-
 G_END_DECLS
 
 #endif /* __GEDIT_WINDOW_ACTIVATABLE_H__ */
+
+/* ex:set ts=8 noet: */
